[rrd-developers] [PATCH] Add rrd_update_v_r to librrd

Frederik Kriewitz frederik at kriewitz.eu
Wed Apr 14 12:11:38 CEST 2010


Add rrd_update_v_r to librrd

Index: src/rrd_update.c
===================================================================
--- src/rrd_update.c	(revision 2068)
+++ src/rrd_update.c	(working copy)
@@ -477,6 +477,16 @@
     return _rrd_update(filename, tmplt, argc, argv, NULL);
 }

+int rrd_update_v_r(
+    const char *filename,
+    const char *tmplt,
+    int argc,
+    const char **argv,
+    rrd_info_t * pcdp_summary)
+{
+    return _rrd_update(filename, tmplt, argc, argv, pcdp_summary);
+}
+
 int _rrd_update(
     const char *filename,
     const char *tmplt,
Index: src/librrd.sym.in.in
===================================================================
--- src/librrd.sym.in.in	(revision 2068)
+++ src/librrd.sym.in.in	(working copy)
@@ -56,6 +56,7 @@
 rrd_update
 rrd_update_r
 rrd_update_v
+rrd_update_v_r
 rrd_version
 rrd_write
 rrd_xport
Index: src/rrd.h
===================================================================
--- src/rrd.h	(revision 2068)
+++ src/rrd.h	(working copy)
@@ -226,14 +226,20 @@
     const char **argv);
     rrd_info_t *rrd_info_r(
     char *);
-/* NOTE: rrd_update_r are only thread-safe if no at-style time
-   specifications get used!!! */
+/* NOTE: rrd_update_r and rrd_update_v_r are only thread-safe if no at-style
+   time specifications get used!!! */

     int       rrd_update_r(
     const char *filename,
     const char *_template,
     int argc,
     const char **argv);
+    int       rrd_update_v_r(
+    const char *filename,
+    const char *_template,
+    int argc,
+    const char **argv,
+    rrd_info_t * pcdp_summary);
     int rrd_fetch_r (
             const char *filename,
             const char *cf,



More information about the rrd-developers mailing list